package pathgame.rendering;

import pathgame.tilemap.Tile;
import pathgame.tilemap.TileMap;
import pathgame.tilemap.Tiles;

public class TileRenderer
{
    /** The unscaled render size of a map tile. */
    public final static float TILE_SIZE = 32;
    
    private static TileTextureProvider[] tProviders = new TileTextureProvider[8];
    
    private static void register(Tile t, TileTextureProvider provider)
    {
        if(t.getId() >= tProviders.length)
        {
            TileTextureProvider[] newTProviders = new TileTextureProvider[tProviders.length * 2];
            System.arraycopy(tProviders, 0, newTProviders, 0, tProviders.length);
            tProviders = newTProviders;
        }
        tProviders[t.getId()] = provider;
    }
    
    static
    {
        register(Tiles.GRASS, new StaticTextureProvider(TileTexture.fromTextureId(0)));
        register(Tiles.GRASS_WITH_STONE, new StaticTextureProvider(TileTexture.fromTextureId(1)));
        register(Tiles.GRASS_WITH_6_BUSHES, new StaticTextureProvider(TileTexture.fromTextureId(2)));
        register(Tiles.GRASS_WITH_3_BUSHES, new StaticTextureProvider(TileTexture.fromTextureId(3)));
        register(Tiles.GRASS_WITH_FLOWERS, new StaticTextureProvider(TileTexture.fromTextureId(4)));
        register(Tiles.GRASS_WITH_HILL, new StaticTextureProvider(TileTexture.fromTextureId(5)));
        register(Tiles.GRASS_WITH_EARTH, new StaticTextureProvider(TileTexture.fromTextureId(6)));
        register(Tiles.FOREST, new StaticTextureProvider(TileTexture.fromTextureId(7)));
        register(Tiles.SHALLOW_WATER, new StaticTextureProvider(TileTexture.fromTextureId(8)));
        register(Tiles.DEEP_WATER, new StaticTextureProvider(TileTexture.fromTextureId(9)));
        register(Tiles.HILL, new StaticTextureProvider(TileTexture.fromTextureId(10)));
        register(Tiles.MOUNTAIN, new StaticTextureProvider(TileTexture.fromTextureId(11)));
    }
    
    public static TileTexture getTileTexture(TileMap map, Tile t, int x, int y)
    {
        if(t == null)
        {
            return null;
        }
        int id = t.getId();
        if(id < 0 || id >= tProviders.length || tProviders[id] == null)
        {
            return null;
        }
        return tProviders[id].getTexture(map, t, x, y);
    }
}
