package pathgame.tilemap;

import java.util.Random;

public class HighMap
{
    public static HighMap generate(int width, int height, float zoom)
    {
        HighMap map = new HighMap(width, height);
        map.zoom(zoom);
        return map;
    }
    
    private final int width;
    private final int height;
    private final float data[][];
    private final Random r = new Random(0);
    
    private HighMap(int width, int height)
    {
        this.width = width;
        this.height = height;
        this.data = new float[width][height];
    }
    
    public float get(int x, int y)
    {
        return data[x][y];
    }
    
    private float[][] randomizeBase()
    {
        float[][] base = new float[width][height];
        for(int x = 0; x < width; x++)
        {
            for(int y = 0; y < height; y++)
            {
                base[x][y] = r.nextFloat();
            }
        }
        return base;
    }
    
    private float smooth(float[][] base, float x1, float y1)
    {
        // distance to next exact pixel
        float fractX = x1 - (int) x1;
        float fractY = y1 - (int) y1;

        // neighbour pixel coords
        int x2 = ((int) x1 + 1) % width;
        int y2 = ((int) y1 + 1) % height;
        
        // interpolate over all 4 pixels, strength varies with distance
        float value = 0.0f;
        value += (1 - fractX) * (1 - fractY) * base[(int) x1][(int) y1];
        value += (1 - fractX) * fractY * base[(int) x1][(int) y2];
        value += fractX * (1 - fractY) * base[(int) x2][(int) y1];
        value += fractX * fractY * base[(int) x2][(int) y2];
        return value;
    }
    
    private float turbulence(float[][] base, float x1, float y1, float factor)
    {
        float sum = 0.0f;
        while(factor >= 1)
        {
            sum += smooth(base, x1 / factor, y1 / factor) * factor;
            factor *= 0.5f;
        }
        return sum;
    }
    
    private void zoom(float factor)
    {
        float[][] base = randomizeBase();
        
        float min = Float.MAX_VALUE;
        float max = Float.MIN_VALUE;
    
        for(int x = 0; x < width; x++)
        {
            for(int y = 0; y < height; y++)
            {
                float f = turbulence(base, x, y, factor);
                data[x][y] = f;
                if(f < min)
                {
                    min = f;
                }
                if(f > max)
                {
                    max = f;
                }
            }
        }
        
        float f = 1.0f / (max - min);
        for(int x = 0; x < width; x++)
        {
            for(int y = 0; y < height; y++)
            {
                data[x][y] = (data[x][y] - min) * f;
            }
        }
    }
}
