package pathgame.tilemap;

/** Fixed size container for tile maps. Changes are stored in a dirty flag,
 * which can be used for rendering.
 *
 * @author kajetan
 */
public class TileMap
{
    private final int width;
    private final int height;
    private final int[][] tiles;
    private boolean dirty = true;
    
    /** Creates a new tile map of the given size.
     *
     * @param width the width of the map
     * @param height the height of the map
     */
    public TileMap(int width, int height)
    {
        this.width = width;
        this.height = height;
        tiles = new int[width][height];
    }
    
    /** Returns the width of the map.
     *
     * @return the width of the map
     */
    public int getWidth()
    {
        return width;
    }

    /** Returns the height of the map.
     *
     * @return the height of the map
     */
    public int getHeight()
    {
        return height;
    }
    
    /** Sets the tile at the given map position. The dirty flag is set.
     *
     * @param x the x coordinate of the tile
     * @param y the y coordinate of the tile
     * @param tile a tile
     */
    public void setTile(int x, int y, Tile tile)
    {
        dirty = true;
        tiles[x][y] = tile.getId();
    }
    
    /** Returns the tile at the given map position or null if the tile is invalid.
     *
     * @param x the x coordinate of the tile
     * @param y the y coordinate of the tile
     * @return the tile at the given map position or null if the tile is invalid
     */
    public Tile getTile(int x, int y)
    {
        return Tile.fromId(tiles[x][y]);
    }

    /** Returns true if the map was modified. This is used for rendering.
     *
     * @return true if the map was modified
     */
    public boolean isDirty()
    {
        return dirty;
    }
    
    /** Clears the dirty flag of the map.
     *
     */
    public void clean()
    {
        dirty = false;
    }
    
}

