package pathgame.tilemap;

import java.util.Random;
import java.util.TreeMap;

public class TileMapGenerator
{
    private static final TreeMap<Integer, Tile> GRASS_MAP = new TreeMap<>();
    
    static
    {
        GRASS_MAP.put(0, Tiles.GRASS);
        GRASS_MAP.put(70, Tiles.GRASS_WITH_STONE);
        GRASS_MAP.put(75, Tiles.GRASS_WITH_6_BUSHES);
        GRASS_MAP.put(80, Tiles.GRASS_WITH_3_BUSHES);
        GRASS_MAP.put(85, Tiles.GRASS_WITH_FLOWERS);
        GRASS_MAP.put(90, Tiles.GRASS_WITH_HILL);
        GRASS_MAP.put(95, Tiles.GRASS_WITH_EARTH);
    }
    
    /** Returns a random test map.
     *
     * @param width the width of the map
     * @param height the height of the map
     * @return a random test map
     */
    public static TileMap getMap(int width, int height)
    {
        Random r = new Random();
        
        HighMap highMap = HighMap.generate(width, height, Math.min(width, height) * 0.125f);
        
        TileMap map = new TileMap(width, height);
        for(int x = 0; x < width; x++)
        {
            for(int y = 0; y < height; y++)
            {
                switch((int) (highMap.get(x, y) * 5))
                {
                    case 0: map.setTile(x, y, Tiles.DEEP_WATER); break;
                    case 1: map.setTile(x, y, Tiles.SHALLOW_WATER); break;
                    case 2: map.setTile(x, y, randomGrass(r)); break;
                    case 3: map.setTile(x, y, Tiles.FOREST); break;
                    case 4: map.setTile(x, y, Tiles.FOREST); break;
                }
            }
        }
        return map;
    }
    
    private static Tile randomGrass(Random r)
    {
        return GRASS_MAP.floorEntry(r.nextInt(100)).getValue();
    }
}
